@@ -1,7 +1,10 @@
 #!/usr/bin/env python3
 # coding: utf-8
 
-__version__ = '0.3.3'
+__version__ = '0.3.4'
+
+if __name__ == '__main__':
+    print(__version__)
 
 from volkanic.cmdline import CommandRegistry
 from volkanic.environ import GlobalInterface
