@@ -92,7 +92,7 @@ class GlobalInterface(metaclass=_GIMeta):
         return '{}_{}'.format(cls.identifier, name).upper()
 
     @classmethod
-    def _get_conf_search_paths(cls):
+    def _get_conf_paths(cls):
         """
         Make sure this method can be called without arguments.
         Override this method in your subclasses for your specific project.
@@ -107,12 +107,18 @@ class GlobalInterface(metaclass=_GIMeta):
             '/{}/config.json5'.format(pn),
         ]
 
+    _get_conf_search_paths = _get_conf_paths
+
     @classmethod
     def _locate_conf(cls):
         """
         Returns: (str) absolute path to config file
         """
-        for path in cls._get_conf_search_paths():
+        func = getattr(cls, '_get_conf_search_paths', None)
+        if func is None:
+            func = cls._get_conf_paths
+        paths = func()
+        for path in paths:
             if not path:
                 continue
             if os.path.exists(path):
@@ -136,16 +142,11 @@ class GlobalInterface(metaclass=_GIMeta):
 
     @staticmethod
     def under_home_dir(*paths):
-        if sys.platform == 'win32':
-            homedir = os.environ["HOMEPATH"]
-        else:
-            homedir = os.path.expanduser('~')
-        return utils.abs_path_join(homedir, *paths)
+        return utils.under_home_dir(*paths)
 
     @classmethod
     def under_package_dir(cls, *paths) -> str:
-        mod = importlib.import_module(cls.package_name)
-        return utils.under_parent_dir(mod.__file__, *paths)
+        return utils.under_package_dir(cls.package_name, *paths)
 
     @classmethod
     def under_project_dir(cls, *paths):
