@@ -6,12 +6,23 @@ import os
 import sys
 
 
-def query_attr(obj, *names):
-    for x in names:
+def attr_query(obj, *attrnames):
+    for x in attrnames:
         obj = getattr(obj, x)
     return obj
 
 
+def attr_setdefault(obj, attrname, value):
+    try:
+        return getattr(obj, attrname)
+    except AttributeError:
+        setattr(obj, attrname, value)
+        return value
+
+
+query_attr = attr_query
+
+
 def merge_dicts(*dicts):
     retdic = {}
     for dic in dicts:
@@ -41,15 +52,19 @@ def load_variables(*contexts):
     return scope
 
 
-def abs_path_join(*paths):
+def _abs_path_join(*paths):
+    path = os.path.join(*paths)
+    return os.path.abspath(path)
+
+
+def abs_path_join(*paths) -> str:
     if not paths:
         msg = 'abs_path_join() requires at least 1 argument'
         raise TypeError(msg)
     if paths[0].startswith('~'):
         paths = list(paths)
         paths[0] = os.path.expanduser(paths[0])
-    path = os.path.join(*paths)
-    return os.path.abspath(path)
+    return _abs_path_join(*paths)
 
 
 def abs_path_join_and_mkdirs(*paths):
@@ -67,6 +82,21 @@ def under_parent_dir(ref_path: str, *paths) -> str:
     return abs_path_join(parent_dir, *paths)
 
 
+def under_home_dir(*paths):
+    if sys.platform == 'win32':
+        homedir = os.environ["HOMEPATH"]
+    else:
+        homedir = os.path.expanduser('~')
+    return _abs_path_join(homedir, *paths)
+
+
+def under_package_dir(package, *paths):
+    if isinstance(package, str):
+        package = importlib.import_module(package)
+    pkg_dir = os.path.dirname(package.__file__)
+    return _abs_path_join(pkg_dir, *paths)
+
+
 def _linux_open(path):
     import subprocess
     subprocess.run(['xdg-open', path])
